@@ -318,7 +318,8 @@ static int time_clock_to_frames(mlt_property self, const char *s, double fps, ml
     s = copy;
     pos = strrchr(s, ':');
 
-#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L)
+#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L) \
+    && !defined(__OpenBSD__)
     char *orig_localename = NULL;
     if (locale) {
         // Protect damaging the global locale from a temporary locale on another thread.
@@ -333,7 +334,7 @@ static int time_clock_to_frames(mlt_property self, const char *s, double fps, ml
 #endif
 
     if (pos) {
-#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L)
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L) && !defined(__OpenBSD__)
         if (locale)
             seconds = strtod_l(pos + 1, NULL, locale);
         else
@@ -349,7 +350,7 @@ static int time_clock_to_frames(mlt_property self, const char *s, double fps, ml
             minutes = atoi(s);
         }
     } else {
-#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L)
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L) && !defined(__OpenBSD__)
         if (locale)
             seconds = strtod_l(s, NULL, locale);
         else
@@ -357,7 +358,8 @@ static int time_clock_to_frames(mlt_property self, const char *s, double fps, ml
             seconds = strtod(s, NULL);
     }
 
-#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L)
+#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L) \
+    && !defined(__OpenBSD__)
     if (locale) {
         // Restore the current locale
         setlocale(LC_NUMERIC, orig_localename);
@@ -521,7 +523,7 @@ static double mlt_property_atof(mlt_property self, double fps, mlt_locale_t loca
         char *end = NULL;
         double result;
 
-#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L)
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L) && !defined(__OpenBSD__)
         if (locale)
             result = strtod_l(value, &end, locale);
         else
@@ -543,7 +545,8 @@ static double mlt_property_atof(mlt_property self, double fps, mlt_locale_t loca
         if (end && end[0] == '%')
             result /= 100.0;
 
-#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L)
+#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L) \
+    && !defined(__OpenBSD__)
         if (locale) {
             // Restore the current locale
             setlocale(LC_NUMERIC, orig_localename);
@@ -1150,7 +1153,7 @@ int mlt_property_is_numeric(mlt_property self, mlt_locale_t locale)
     if ((!result && self->types & mlt_prop_string) && self->prop_string) {
         char *p = NULL;
 
-#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L)
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L) && !defined(__OpenBSD__)
         if (locale)
             strtod_l(self->prop_string, &p, locale);
         else
@@ -1170,7 +1173,8 @@ int mlt_property_is_numeric(mlt_property self, mlt_locale_t locale)
 
             strtod(self->prop_string, &p);
 
-#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L)
+#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L) \
+    && !defined(__OpenBSD__)
         if (locale) {
             // Restore the current locale
             setlocale(LC_NUMERIC, orig_localename);
@@ -1885,7 +1889,8 @@ mlt_rect mlt_property_get_rect(mlt_property self, mlt_locale_t locale)
         char *p = NULL;
         int count = 0;
 
-#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L)
+#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L) \
+    && !defined(__OpenBSD__)
         char *orig_localename = NULL;
         if (locale) {
             // Protect damaging the global locale from a temporary locale on another thread.
@@ -1901,7 +1906,7 @@ mlt_rect mlt_property_get_rect(mlt_property self, mlt_locale_t locale)
 
         while (*value) {
             double temp;
-#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L)
+#if defined(__GLIBC__) || defined(__APPLE__) || defined(HAVE_STRTOD_L) && !defined(__OpenBSD__)
             if (locale)
                 temp = strtod_l(value, &p, locale);
             else
@@ -1942,7 +1947,8 @@ mlt_rect mlt_property_get_rect(mlt_property self, mlt_locale_t locale)
             count++;
         }
 
-#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L)
+#if !defined(__GLIBC__) && !defined(__APPLE__) && !defined(_WIN32) && !defined(HAVE_STRTOD_L) \
+    && !defined(__OpenBSD__)
         if (locale) {
             // Restore the current locale
             setlocale(LC_NUMERIC, orig_localename);
