@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef MLT_TOKENISER_H
@@ -29,21 +29,20 @@
 
 typedef struct
 {
-	char *input;
-	char **tokens;
-	int count;
-	int size;
-}
-*mlt_tokeniser, mlt_tokeniser_t;
+    char *input;
+    char **tokens;
+    int count;
+    int size;
+} * mlt_tokeniser, mlt_tokeniser_t;
 
 /* Remote parser API.
 */
 
-extern mlt_tokeniser mlt_tokeniser_init( );
-extern int mlt_tokeniser_parse_new( mlt_tokeniser tokeniser, char *text, const char *delimiter );
-extern char *mlt_tokeniser_get_input( mlt_tokeniser tokeniser );
-extern int mlt_tokeniser_count( mlt_tokeniser tokeniser );
-extern char *mlt_tokeniser_get_string( mlt_tokeniser tokeniser, int index );
-extern void mlt_tokeniser_close( mlt_tokeniser tokeniser );
+extern mlt_tokeniser mlt_tokeniser_init();
+extern int mlt_tokeniser_parse_new(mlt_tokeniser tokeniser, char *text, const char *delimiter);
+extern char *mlt_tokeniser_get_input(mlt_tokeniser tokeniser);
+extern int mlt_tokeniser_count(mlt_tokeniser tokeniser);
+extern char *mlt_tokeniser_get_string(mlt_tokeniser tokeniser, int index);
+extern void mlt_tokeniser_close(mlt_tokeniser tokeniser);
 
 #endif
