@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #include "video_format.hpp"
 
 #include <mutex>
@@ -14,6 +20,7 @@ extern "C" {
 
 #include "app/qstring_exception.hpp"
 #include "app/log/log.hpp"
+#include "model/assets/composition.hpp"
 
 namespace glaxnimate::av {
 
@@ -288,6 +295,7 @@ private:
     AVDictionary* local_dict = nullptr;
 };
 
+
 class Video
 {
 public:
@@ -362,13 +370,39 @@ public:
         }
     }
 
-    Video(AVFormatContext *oc, Dict options, int64_t bit_rate, int width, int height, int fps)
-        : ost(oc, oc->oformat->video_codec)
+    static AVPixelFormat best_pixel_format(const AVPixelFormat* pix_fmts)
+    {
+        static const std::array<AVPixelFormat, 8> preferred = {
+            // RGBA and similar (no conversion)
+            AV_PIX_FMT_ARGB, AV_PIX_FMT_RGBA, AV_PIX_FMT_ABGR, AV_PIX_FMT_BGRA,
+            // YUV + Alpha
+            AV_PIX_FMT_YUVA444P, AV_PIX_FMT_YUVA420P,
+            // RGB
+            AV_PIX_FMT_RGB24, AV_PIX_FMT_BGR24,
+
+        };
+
+        if ( !pix_fmts )
+            return AV_PIX_FMT_NONE;
+
+        std::set<AVPixelFormat> supported;
+        for ( auto it = pix_fmts; it && *it != AV_PIX_FMT_NONE; ++it )
+            supported.insert(*it);
+
+        for ( auto pref : preferred )
+            if ( supported.count(pref) )
+                return pref;
+
+        return *pix_fmts;
+    }
+
+    Video(AVFormatContext *oc, Dict options, AVCodecID codec_id, int64_t bit_rate, int width, int height, int fps)
+        : ost(oc, codec_id)
     {
         if ( ost.codec->type != AVMEDIA_TYPE_VIDEO )
             throw Error(QObject::tr("No video codec"));
 
-        ost.codec_context->codec_id = oc->oformat->video_codec;
+        ost.codec_context->codec_id = codec_id;
 
         ost.codec_context->bit_rate = bit_rate;
 
@@ -389,21 +423,16 @@ public:
 
         // emit one intra frame every twelve frames at most
         ost.codec_context->gop_size = 12;
-        // get_format() for some reason returns an invalid value
-        if (ost.codec->id == AV_CODEC_ID_VP9 || ost.codec->id == AV_CODEC_ID_VP8)
-        {
-            ost.codec_context->pix_fmt = AV_PIX_FMT_YUVA420P;
-        }
-        else
-        {
-            if ( ost.codec->pix_fmts == nullptr )
-                throw av::Error(QObject::tr("Could not determine pixel format"));
-            ost.codec_context->pix_fmt = ost.codec->pix_fmts[0];
-        }
 
-        // just for testing, we also add B-frames
-        if ( ost.codec_context->codec_id == AV_CODEC_ID_MPEG2VIDEO )
-            ost.codec_context->max_b_frames = 2;
+        // get_format() for some reason returns an invalid value
+        ost.codec_context->pix_fmt = best_pixel_format(ost.codec->pix_fmts);
+
+        if ( ost.codec_context->pix_fmt == AV_PIX_FMT_NONE )
+                throw av::Error(QObject::tr("Could not determine pixel format"));
+
+//         // just for testing, we also add B-frames
+//         if ( ost.codec_context->codec_id == AV_CODEC_ID_MPEG2VIDEO )
+//             ost.codec_context->max_b_frames = 2;
 
         int ret;
         // open the codec
@@ -657,21 +686,27 @@ glaxnimate::io::Autoreg<glaxnimate::io::video::VideoFormat> glaxnimate::io::vide
 
 static QStringList out_ext;
 
-static void get_formats()
+static bool format_skip(const AVOutputFormat* format)
 {
-    std::set<std::string> blacklisted = {
+    static std::set<std::string> blacklisted = {
         "webp", "gif", "ico"
     };
+
+    return
+        blacklisted.count(format->name) ||
+        format->video_codec == AV_CODEC_ID_NONE ||
+        format->flags & (AVFMT_NOFILE|AVFMT_NEEDNUMBER)
+    ;
+}
+
+static void get_formats()
+{
     out_ext.push_back("mp4");
 
     void* opaque = nullptr;
     while ( auto format = av_muxer_iterate(&opaque) )
     {
-        if (
-            blacklisted.count(format->name) ||
-            format->video_codec == AV_CODEC_ID_NONE ||
-            format->flags & (AVFMT_NOFILE|AVFMT_NEEDNUMBER)
-        )
+        if ( format_skip(format) )
             continue;
 
         out_ext += QString(format->extensions).split(',',
@@ -691,7 +726,8 @@ QStringList glaxnimate::io::video::VideoFormat::extensions() const
     return out_ext;
 }
 
-bool glaxnimate::io::video::VideoFormat::on_save(QIODevice& dev, const QString& name, model::Document* document, const QVariantMap& settings)
+
+bool glaxnimate::io::video::VideoFormat::on_save(QIODevice& dev, const QString& name, model::Composition* comp, const QVariantMap& settings)
 {
     try
     {
@@ -699,48 +735,28 @@ bool glaxnimate::io::video::VideoFormat::on_save(QIODevice& dev, const QString&
 
         auto filename = name.toUtf8();
 
-
-        av::Dict opt;
-        /*
-        for (int i = 2; i+1 < argc; i+=2) {
-            if (!strcmp(argv[i], "-flags") || !strcmp(argv[i], "-fflags"))
-                av_dict_set(&opt, argv[i]+1, argv[i+1], 0);
-        }
-        */
-
         // allocate the output media context
         AVFormatContext *oc;
 
-        QString format_hint = settings["format"].toString();
-        if ( !format_hint.isEmpty() )
-        {
-            avformat_alloc_output_context2(&oc, nullptr, format_hint.toUtf8().data(), filename.data());
-            if ( !oc )
-            {
-                error(tr("Format not supported: %1").arg(format_hint));
-                return false;
-            }
-        }
-        else
-        {
-            avformat_alloc_output_context2(&oc, nullptr, nullptr, filename.data());
+        avformat_alloc_output_context2(&oc, nullptr, nullptr, filename.data());
 
+        if ( !oc )
+        {
+            warning(tr("Could not deduce output format from file extension: using MPEG."));
+            avformat_alloc_output_context2(&oc, nullptr, "mpeg", filename.data());
             if ( !oc )
             {
-                warning(tr("Could not deduce output format from file extension: using MPEG."));
-                avformat_alloc_output_context2(&oc, nullptr, "mpeg", filename.data());
-                if ( !oc )
-                {
-                    error(tr("Could not find output format"));
-                    return false;
-                }
+                error(tr("Could not find output format"));
+                return false;
             }
         }
 
         // see https://libav.org/documentation/doxygen/master/group__metadata__api.html
         av::DictWrapper metadata(&oc->metadata);
 
-        metadata["title"] = document->main()->name.get();
+        auto document = comp->document();
+
+        metadata["title"] = comp->name.get();
 
         if ( !document->info().author.isEmpty() )
             metadata["artist"] = document->info().author;
@@ -753,25 +769,44 @@ bool glaxnimate::io::video::VideoFormat::on_save(QIODevice& dev, const QString&
 
         av::CGuard guard(&avformat_free_context, oc);
 
-        // Add the audio and video streams using the default format codecs
-        // and initialize the codecs.
-        if ( oc->oformat->video_codec == AV_CODEC_ID_NONE )
+        // Add the audio and video streams using the given (or default)
+        // format codecs and initialize the codecs.
+        AVCodecID codec_id = oc->oformat->video_codec;
+        if ( codec_id == AV_CODEC_ID_NONE )
         {
             error(tr("No video codec"));
             return false;
         }
 
+        // Options
+        av::Dict opt;
+        opt["crf"] = 23;
+        if ( codec_id == AV_CODEC_ID_H264 )
+        {
+            opt["profile"] = "high";
+            opt["preset"] = "veryslow";
+            opt["tune"] = "animation";
+        }
+
+        for ( auto it = settings.begin(); it != settings.end(); ++it )
+        {
+            if ( it.key().startsWith("ffmpeg:") )
+            {
+                auto value = it->toString();
+                opt[it.key().mid(7)] = value;
+            }
+        }
+
         // Now that all the parameters are set, we can open the audio and
         // video codecs and allocate the necessary encode buffers.
         int width = settings["width"].toInt();
         if ( width == 0 )
-            width = document->main()->width.get();
+            width = comp->width.get();
         int height = settings["height"].toInt();
         if ( height == 0 )
-            height = document->main()->height.get();
-        int64_t bit_rate = settings["bit_rate"].toInt();
-        int fps = qRound(document->main()->fps.get());
-        av::Video video(oc, opt, bit_rate*100, width, height, fps);
+            height = comp->height.get();
+        int fps = qRound(comp->fps.get());
+        av::Video video(oc, opt, codec_id, 7000000, width, height, fps);
 
         // log format info
         av_dump_format(oc, 0, filename, 1);
@@ -788,13 +823,13 @@ bool glaxnimate::io::video::VideoFormat::on_save(QIODevice& dev, const QString&
             return false;
         }
 
-        auto first_frame = document->main()->animation->first_frame.get();
-        auto last_frame = document->main()->animation->last_frame.get();
+        auto first_frame = comp->animation->first_frame.get();
+        auto last_frame = comp->animation->last_frame.get();
         QColor background = settings["background"].value<QColor>();
         emit progress_max_changed(last_frame - first_frame);
         for ( auto i = first_frame; i < last_frame; i++ )
         {
-            video.write_video_frame(document->render_image(i, {width, height}, background));
+            video.write_video_frame(comp->render_image(i, {width, height}, background));
             emit progress(i - first_frame);
         }
 
@@ -815,15 +850,14 @@ bool glaxnimate::io::video::VideoFormat::on_save(QIODevice& dev, const QString&
     }
 }
 
-std::unique_ptr<app::settings::SettingsGroup> glaxnimate::io::video::VideoFormat::save_settings(model::Document* document) const
+std::unique_ptr<app::settings::SettingsGroup> glaxnimate::io::video::VideoFormat::save_settings(model::Composition* comp) const
 {
     return std::make_unique<app::settings::SettingsGroup>(app::settings::SettingList{
-        //                      slug            label           description                                         default min max
-        app::settings::Setting{"bit_rate",   tr("Bitrate"),      tr("Video bit rate"),                               5000,   0, 10000},
-        app::settings::Setting{"background", tr("Background"),   tr("Background color"),                             QColor(0, 0, 0, 0)},
-        app::settings::Setting{"width",      tr("Width"),        tr("If not 0, it will overwrite the size"),         document->main()->width.get(), 0, 10000},
-        app::settings::Setting{"height",     tr("Height"),       tr("If not 0, it will overwrite the size"),         document->main()->height.get(),0, 10000},
-        app::settings::Setting{"verbose",    tr("Verbose"),      tr("Show verbose information on the conversion"),   false},
+        //                      slug            label             description                                           default             min max
+        app::settings::Setting{"background",    tr("Background"), tr("Background color"),                               QColor(0, 0, 0, 0)},
+        app::settings::Setting{"width",         tr("Width"),      tr("If not 0, it will overwrite the size"),           comp->width.get(),  0, 99999},
+        app::settings::Setting{"height",        tr("Height"),     tr("If not 0, it will overwrite the size"),           comp->height.get(), 0, 99999},
+        app::settings::Setting{"verbose",       tr("Verbose"),    tr("Show verbose information on the conversion"),     false},
     });
 }
 
